@@ -1,5 +1,5 @@
 #file: base_screen.py
-#Copyright (C) 2005,2006 Evil Mr Henry and Phil Bordelon
+#Copyright (C) 2005, 2006, 2007 Evil Mr Henry, Phil Bordelon, and Brian Reid
 #This file is part of Endgame: Singularity.
 
 #Endgame: Singularity is free software; you can redistribute it and/or modify
@@ -28,7 +28,7 @@ import listbox
 #cost = (money, ptime, labor)
 #detection = (news, science, covert, person)
 
-def show_base(base, location):
+def show_base(this_base, location):
     #Border
     g.screen.fill(g.colors["black"])
 
@@ -80,7 +80,7 @@ def show_base(base, location):
 
     sel_button = -1
 
-    refresh_base(menu_buttons, base)
+    refresh_base(menu_buttons, this_base)
     while 1:
         g.clock.tick(20)
         for event in pygame.event.get():
@@ -99,24 +99,24 @@ def show_base(base, location):
                         return 0
                     if button.button_id == "CHANGE":
                         g.play_click()
-                        change_tech(base)
-                        refresh_base(menu_buttons, base)
+                        change_tech(this_base)
+                        refresh_base(menu_buttons, this_base)
                     elif button.button_id == "C_PROCESSOR":
                         g.play_click()
-                        build_item(base, "compute", location)
-                        refresh_base(menu_buttons, base)
+                        build_item(this_base, "compute", location)
+                        refresh_base(menu_buttons, this_base)
                     elif button.button_id == "C_REACTOR":
                         g.play_click()
-                        build_item(base, "react", location)
-                        refresh_base(menu_buttons, base)
+                        build_item(this_base, "react", location)
+                        refresh_base(menu_buttons, this_base)
                     elif button.button_id == "C_NETWORK":
                         g.play_click()
-                        build_item(base, "network", location)
-                        refresh_base(menu_buttons, base)
+                        build_item(this_base, "network", location)
+                        refresh_base(menu_buttons, this_base)
                     elif button.button_id == "C_SECURITY":
                         g.play_click()
-                        build_item(base, "security", location)
-                        refresh_base(menu_buttons, base)
+                        build_item(this_base, "security", location)
+                        refresh_base(menu_buttons, this_base)
                     elif button.button_id == "<":
                         g.play_click()
                         return -1
@@ -130,28 +130,28 @@ def show_base(base, location):
                                 g.colors["white"]):
                             g.play_click()
                             return -2
-                        else: refresh_base(menu_buttons, base)
+                        else: refresh_base(menu_buttons, this_base)
                     elif button.xy[1] != -1 and button.xy[1] != 25 and \
                             button.xy[1] != g.screen_size[1]-25:
                         if button.xy[0] == event.pos[0] or \
                                 button.xy[1] == event.pos[1]: continue
                         g.play_click()
-                        build_item(base, location)
-                        refresh_base(menu_buttons, base)
+                        build_item(this_base, location)
+                        refresh_base(menu_buttons, this_base)
 
-def refresh_base(menu_buttons, base):
+def refresh_base(menu_buttons, this_base):
     g.screen.fill(g.colors["black"])
-# 	xstart = g.screen_size[0]/2-base.base_type.size[0]*9
-# 	ystart = g.screen_size[1]/2-base.base_type.size[1]*9
+# 	xstart = g.screen_size[0]/2-this_base.this_base_type.size[0]*9
+# 	ystart = g.screen_size[1]/2-this_base.this_base_type.size[1]*9
     xstart = 10
     ystart = 50
 
     #base name display
-    menu_buttons[11].text = base.name
+    menu_buttons[11].text = this_base.name
     menu_buttons[11].remake_button()
 
     #detection chance display
-    d_chance = base.get_d_chance()
+    d_chance = this_base.get_d_chance()
     menu_buttons[1].text = g.strings["detect_chance"]+" NEWS: "+ \
         g.to_percent(d_chance[0])+"  SCIENCE: "+ \
         g.to_percent(d_chance[1])+"  COVERT: "+ \
@@ -160,15 +160,17 @@ def refresh_base(menu_buttons, base):
     menu_buttons[1].remake_button()
 
     #research display
-    if base.studying != "":
-        if g.jobs.has_key(base.studying) == 0:
-            if g.techs[base.studying].known == 1: base.studying = ""
+    if this_base.studying != "" and this_base.studying != "Construction":
+        if g.jobs.has_key(this_base.studying) == 0:
+            if g.techs[this_base.studying].known == 1: this_base.studying = ""
 
     action_display_string = "STUDYING: "
 
-    study_display_string = base.studying
+    study_display_string = this_base.studying
     if study_display_string == "":
         study_display_string = "NOTHING"
+    elif study_display_string == "Construction":
+        study_display_string = "CONSTRUCTION"
     elif g.jobs.has_key(study_display_string):
         action_display_string = "WORKING: "
     elif g.techs.has_key(study_display_string):
@@ -179,44 +181,44 @@ def refresh_base(menu_buttons, base):
     g.screen.fill(g.colors["white"], (xstart, ystart, 300, g.screen_size[1]-150))
     g.screen.fill(g.colors["dark_blue"], (xstart+1, ystart+1, 298, g.screen_size[1]-152))
 
-    if base.usage[0] == 0: item_name = "None"
-    else: item_name = base.usage[0].item_type.name+" x "+str(base.has_item())
+    if this_base.usage[0] == 0: item_name = "None"
+    else: item_name = this_base.usage[0].item_type.name+" x "+str(this_base.has_item())
     g.print_string(g.screen, "Processor: " + item_name,
         g.font[0][18], -1, (xstart+5, ystart+15), g.colors["white"])
-    if base.usage[len(base.usage)-1] != 0:
-        if base.usage[len(base.usage)-1].built == 0:
+    if this_base.usage[len(this_base.usage)-1] != 0:
+        if this_base.usage[len(this_base.usage)-1].built == 0:
             g.print_string(g.screen, "Completion in " +
-                g.to_time(base.usage[len(base.usage)-1].cost[2]),
+                g.to_time(this_base.usage[len(this_base.usage)-1].cost[2]),
                 g.font[0][18], -1, (xstart+5, ystart+30), g.colors["white"])
 
-    if base.extra_items[0] == 0: item_name = "None"
-    else: item_name = base.extra_items[0].item_type.name
+    if this_base.extra_items[0] == 0: item_name = "None"
+    else: item_name = this_base.extra_items[0].item_type.name
     g.print_string(g.screen, "Reactor: " + item_name,
         g.font[0][18], -1, (xstart+5, ystart+65), g.colors["white"])
-    if base.extra_items[0] != 0:
-        if base.extra_items[0].built == 0:
+    if this_base.extra_items[0] != 0:
+        if this_base.extra_items[0].built == 0:
             g.print_string(g.screen, "Completion in " +
-                g.to_time(base.extra_items[0].cost[2]),
+                g.to_time(this_base.extra_items[0].cost[2]),
                 g.font[0][18], -1, (xstart+5, ystart+80), g.colors["white"])
 
-    if base.extra_items[1] == 0: item_name = "None"
-    else: item_name = base.extra_items[1].item_type.name
+    if this_base.extra_items[1] == 0: item_name = "None"
+    else: item_name = this_base.extra_items[1].item_type.name
     g.print_string(g.screen, "Network: " + item_name,
         g.font[0][18], -1, (xstart+5, ystart+115), g.colors["white"])
-    if base.extra_items[1] != 0:
-        if base.extra_items[1].built == 0:
+    if this_base.extra_items[1] != 0:
+        if this_base.extra_items[1].built == 0:
             g.print_string(g.screen, "Completion in " +
-                g.to_time(base.extra_items[1].cost[2]),
+                g.to_time(this_base.extra_items[1].cost[2]),
                 g.font[0][18], -1, (xstart+5, ystart+130), g.colors["white"])
 
-    if base.extra_items[2] == 0: item_name = "None"
-    else: item_name = base.extra_items[2].item_type.name
+    if this_base.extra_items[2] == 0: item_name = "None"
+    else: item_name = this_base.extra_items[2].item_type.name
     g.print_string(g.screen, "Security: " + item_name,
         g.font[0][18], -1, (xstart+5, ystart+165), g.colors["white"])
-    if base.extra_items[2] != 0:
-        if base.extra_items[2].built == 0:
+    if this_base.extra_items[2] != 0:
+        if this_base.extra_items[2].built == 0:
             g.print_string(g.screen, "Completion in " +
-                g.to_time(base.extra_items[2].cost[2]),
+                g.to_time(this_base.extra_items[2].cost[2]),
                 g.font[0][18], -1, (xstart+5, ystart+190), g.colors["white"])
 
     for button in menu_buttons:
@@ -224,24 +226,27 @@ def refresh_base(menu_buttons, base):
     pygame.display.flip()
 
 
-def build_item(base, item_type, location):
-    if base.base_type.size == 1:
+def build_item(this_base, item_type, location):
+    if this_base.base_type.size == 1:
         g.create_dialog(g.strings["unbuildable"], g.font[0][18],
             (g.screen_size[0]/2 - 100, 50), (200, 200), g.colors["dark_blue"],
             g.colors["white"], g.colors["white"])
         return 0
 
     list_size = 10
-    item_list = []
+
+    # The object list will hold all of the actual item types buildable.
+    item_object_list = []
+
+    # The ID list holds the 'IDs' of each item, used to refer back to the
+    # source objects.
+    item_id_list = []
+
+    # The display list holds the display names for each object, potentially
+    # localised into the native language.
     item_display_list = []
-    #for item_name in g.items:
-        #if g.items[item_name].item_type == item_type:
-            #if g.items[item_name].prereq == "":
-                #item_list.append(item_name)
-                #item_display_list.append(g.items[item_name].name)
-            #elif g.techs[g.items[item_name].prereq].known == 1:
-                #item_list.append(item_name)
-                #item_display_list.append(g.items[item_name].name)
+
+    # First we determine the list of items that can actually be built here ...
     for item_name in g.items:
         if g.items[item_name].item_type == item_type:
             if g.items[item_name].prereq != "":
@@ -249,16 +254,26 @@ def build_item(base, item_type, location):
                     continue
             try: g.items[item_name].buildable.index(location)
             except ValueError: continue
-            item_list.append(item_name)
-            item_display_list.append(g.items[item_name].name)
+            item_object_list.append(g.items[item_name])
+
+    # ... then we sort that list.  Items sort by cost comparison.  We want to
+    # display the most expensive objects at the top, as they are typically
+    # what a person wants to build.
+    item_object_list.sort()
+    item_object_list.reverse()
+
+    # Finally we build the id_list and display_list from the sorted objects.
+    item_id_list = [x.item_id for x in item_object_list]
+    item_display_list = [x.name for x in item_object_list]
+
     xy_loc = (g.screen_size[0]/2 - 300, 50)
-    while len(item_list) % list_size != 0 or len(item_list) == 0:
-        item_list.append("")
+    while len(item_id_list) % list_size != 0 or len(item_id_list) == 0:
+        item_id_list.append("")
         item_display_list.append("")
 
     list_pos = 0
 
-    item_listbox = listbox.listbox(xy_loc, (250, 300),
+    item_id_listbox = listbox.listbox(xy_loc, (250, 300),
         list_size, 1, g.colors["dark_blue"], g.colors["blue"],
         g.colors["white"], g.colors["white"], g.font[0][18])
 
@@ -274,8 +289,8 @@ def build_item(base, item_type, location):
     for button in menu_buttons:
         button.refresh_button(0)
 
-    refresh_item(base, item_list[list_pos], xy_loc)
-    listbox.refresh_list(item_listbox, item_scroll, list_pos, item_display_list)
+    refresh_item(this_base, item_id_list[list_pos], xy_loc)
+    listbox.refresh_list(item_id_listbox, item_scroll, list_pos, item_display_list)
 
     sel_button = -1
     while 1:
@@ -286,38 +301,38 @@ def build_item(base, item_type, location):
                 if event.key == pygame.K_ESCAPE: return -1
                 elif event.key == pygame.K_q: return -1
                 elif event.key == pygame.K_RETURN:
-                    actual_build(base, item_list[list_pos], item_type)
+                    actual_build(this_base, item_id_list[list_pos], item_type)
                     return
                 else:
-                    list_pos, refresh = item_listbox.key_handler(event.key,
+                    list_pos, refresh = item_id_listbox.key_handler(event.key,
                         list_pos, item_display_list)
                     if refresh:
-                        refresh_item(base, item_list[list_pos], xy_loc)
-                        listbox.refresh_list(item_listbox, item_scroll,
+                        refresh_item(this_base, item_id_list[list_pos], xy_loc)
+                        listbox.refresh_list(item_id_listbox, item_scroll,
                                         list_pos, item_display_list)
 
             elif event.type == pygame.MOUSEBUTTONUP:
                 if event.button == 1:
-                    tmp = item_listbox.is_over(event.pos)
+                    tmp = item_id_listbox.is_over(event.pos)
                     if tmp != -1:
                         list_pos = (list_pos / list_size)*list_size + tmp
-                        refresh_item(base, item_list[list_pos], xy_loc)
-                        listbox.refresh_list(item_listbox, item_scroll,
+                        refresh_item(this_base, item_id_list[list_pos], xy_loc)
+                        listbox.refresh_list(item_id_listbox, item_scroll,
                                         list_pos, item_display_list)
                 if event.button == 3: return -1
                 if event.button == 4:
                     list_pos -= 1
                     if list_pos <= 0:
                         list_pos = 0
-                    refresh_item(base, item_list[list_pos], xy_loc)
-                    listbox.refresh_list(item_listbox, item_scroll,
+                    refresh_item(this_base, item_id_list[list_pos], xy_loc)
+                    listbox.refresh_list(item_id_listbox, item_scroll,
                                         list_pos, item_display_list)
                 if event.button == 5:
                     list_pos += 1
-                    if list_pos >= len(item_list):
-                        list_pos = len(item_list)-1
-                    refresh_item(base, item_list[list_pos], xy_loc)
-                    listbox.refresh_list(item_listbox, item_scroll,
+                    if list_pos >= len(item_id_list):
+                        list_pos = len(item_id_list)-1
+                    refresh_item(this_base, item_id_list[list_pos], xy_loc)
+                    listbox.refresh_list(item_id_listbox, item_scroll,
                                         list_pos, item_display_list)
             elif event.type == pygame.MOUSEMOTION:
                 sel_button = buttons.refresh_buttons(sel_button, menu_buttons, event)
@@ -325,46 +340,46 @@ def build_item(base, item_type, location):
                 if button.was_activated(event):
                     if button.button_id == "BUILD":
                         g.play_click()
-                        actual_build(base, item_list[list_pos], item_type)
+                        actual_build(this_base, item_id_list[list_pos], item_type)
                         return
                     if button.button_id == "BACK":
                         g.play_click()
                         return -1
-            tmp = item_scroll.adjust_pos(event, list_pos, item_list)
+            tmp = item_scroll.adjust_pos(event, list_pos, item_id_list)
             if tmp != list_pos:
                 list_pos = tmp
-                refresh_item(base, item_list[list_pos], xy_loc)
-                listbox.refresh_list(item_listbox, item_scroll, list_pos,
+                refresh_item(this_base, item_id_list[list_pos], xy_loc)
+                listbox.refresh_list(item_id_listbox, item_scroll, list_pos,
                     item_display_list)
 
 
 
-def actual_build(base, item_name, item_type):
+def actual_build(this_base, item_name, item_type):
     if item_name == "": return
     if item_type == "compute":
-        for i in range(len(base.usage)):
-            if base.usage[i] != 0:
-                if base.usage[i].item_type.item_id == \
+        for i in range(len(this_base.usage)):
+            if this_base.usage[i] != 0:
+                if this_base.usage[i].item_type.item_id == \
                         g.items[item_name].item_id:
                     continue
-            base.usage[i] = g.item.item(g.items[item_name])
+            this_base.usage[i] = g.item.item(g.items[item_name])
     elif item_type == "react":
-        if base.extra_items[0] != 0:
-            if base.extra_items[0].item_type.item_id == g.items[item_name].item_id:
+        if this_base.extra_items[0] != 0:
+            if this_base.extra_items[0].item_type.item_id == g.items[item_name].item_id:
                 return
-        base.extra_items[0] = g.item.item(g.items[item_name])
+        this_base.extra_items[0] = g.item.item(g.items[item_name])
     elif item_type == "network":
-        if base.extra_items[1] != 0:
-            if base.extra_items[1].item_type.item_id == g.items[item_name].item_id:
+        if this_base.extra_items[1] != 0:
+            if this_base.extra_items[1].item_type.item_id == g.items[item_name].item_id:
                 return
-        base.extra_items[1] = g.item.item(g.items[item_name])
+        this_base.extra_items[1] = g.item.item(g.items[item_name])
     elif item_type == "security":
-        if base.extra_items[2] != 0:
-            if base.extra_items[2].item_type.item_id == g.items[item_name].item_id:
+        if this_base.extra_items[2] != 0:
+            if this_base.extra_items[2].item_type.item_id == g.items[item_name].item_id:
                 return
-        base.extra_items[2] = g.item.item(g.items[item_name])
+        this_base.extra_items[2] = g.item.item(g.items[item_name])
 
-def refresh_item(base, item_name, xy_loc):
+def refresh_item(this_base, item_name, xy_loc):
     xy = (xy_loc[0]+150, xy_loc[1])
     g.screen.fill(g.colors["white"], (xy[0]+155, xy[1], 300, 350))
     g.screen.fill(g.colors["dark_blue"], (xy[0]+156, xy[1]+1, 298, 348))
@@ -385,7 +400,7 @@ def refresh_item(base, item_name, xy_loc):
 
     string = g.to_money(g.items[item_name].cost[0])+" "+g.strings["money"]
     if g.items[item_name].item_type == "compute":
-        string += " x"+str(base.base_type.size)+"="
+        string += " x"+str(this_base.base_type.size)+"="
     g.print_string(g.screen, string,
             g.font[0][16], -1, (xy[0]+160, xy[1]+80), g.colors["white"])
 
@@ -395,24 +410,32 @@ def refresh_item(base, item_name, xy_loc):
             g.font[0][16], -1, (xy[0]+290, xy[1]+80), g.colors["white"])
 
     if g.items[item_name].item_type == "compute":
-        string = g.to_money(g.items[item_name].cost[0]*base.base_type.size)+" "
+        string = g.to_money(g.items[item_name].cost[0]*this_base.base_type.size)+" "
         string +=g.strings["money"]
+
         g.print_string(g.screen, string,
                 g.font[0][16], -1, (xy[0]+160, xy[1]+100), g.colors["white"])
 
-    x_start = 100
-    if g.items[item_name].item_type == "compute": x_start = 120
+        # Add CPU amount here...
+        string = "Total CPU available: " + g.add_commas(str(g.items[item_name].item_qual*this_base.base_type.size))
+        g.print_string(g.screen, string,
+            g.font[0][16], -1, (xy[0]+160, xy[1]+120), g.colors["white"])
+
+    x_start = 120
+    if g.items[item_name].item_type == "compute": x_start = 140
     g.print_multiline(g.screen, g.items[item_name].descript,
             g.font[0][18], 290, (xy[0]+160, xy[1]+x_start), g.colors["white"])
 
 
-def change_tech(base):
+def change_tech(this_base):
     list_size = 10
 
     item_list = []
     item_list2 = []
     item_list.append("Nothing")
     item_list2.append("Nothing")
+    item_list.append("Construction")
+    item_list2.append("Construction")
     #TECH
     if g.techs["Simulacra"].known == 1:
         item_list.append("Expert Jobs")
@@ -427,7 +450,7 @@ def change_tech(base):
         item_list.append("Menial Jobs")
         item_list2.append("Menial Jobs")
     for tech_name in g.techs:
-        if g.techs[tech_name].known == 0 and base.allow_study(tech_name) == 1:
+        if g.techs[tech_name].known == 0 and this_base.allow_study(tech_name) == 1:
             for tech_pre in g.techs[tech_name].prereq:
                 if g.techs[tech_pre].known == 0:
                     break
@@ -459,7 +482,7 @@ def change_tech(base):
         button.refresh_button(0)
 
 
-    refresh_tech(base, item_list2[list_pos], xy_loc)
+    refresh_tech(this_base, item_list2[list_pos], xy_loc)
     listbox.refresh_list(tech_list, tech_scroll, list_pos, item_list)
 
     sel_button = -1
@@ -471,14 +494,14 @@ def change_tech(base):
                 if event.key == pygame.K_ESCAPE: return -1
                 elif event.key == pygame.K_q: return -1
                 elif event.key == pygame.K_RETURN:
-                    base.studying = item_list2[list_pos]
-                    if base.studying == "Nothing": base.studying = ""
+                    this_base.studying = item_list2[list_pos]
+                    if this_base.studying == "Nothing": this_base.studying = ""
                     return
                 else:
                     list_pos, refresh = tech_list.key_handler(event.key,
                         list_pos, item_list)
                     if refresh:
-                        refresh_tech(base, item_list2[list_pos], xy_loc)
+                        refresh_tech(this_base, item_list2[list_pos], xy_loc)
                         listbox.refresh_list(tech_list, tech_scroll,
                                         list_pos, item_list)
             elif event.type == pygame.MOUSEBUTTONUP:
@@ -486,7 +509,7 @@ def change_tech(base):
                     tmp = tech_list.is_over(event.pos)
                     if tmp != -1:
                         list_pos = (list_pos / list_size)*list_size + tmp
-                        refresh_tech(base, item_list2[list_pos], xy_loc)
+                        refresh_tech(this_base, item_list2[list_pos], xy_loc)
                         listbox.refresh_list(tech_list, tech_scroll,
                                         list_pos, item_list)
                 if event.button == 3: return -1
@@ -494,14 +517,14 @@ def change_tech(base):
                     list_pos -= 1
                     if list_pos <= 0:
                         list_pos = 0
-                    refresh_tech(base, item_list2[list_pos], xy_loc)
+                    refresh_tech(this_base, item_list2[list_pos], xy_loc)
                     listbox.refresh_list(tech_list, tech_scroll,
                                         list_pos, item_list)
                 if event.button == 5:
                     list_pos += 1
                     if list_pos >= len(item_list):
                         list_pos = len(item_list)-1
-                    refresh_tech(base, item_list2[list_pos], xy_loc)
+                    refresh_tech(this_base, item_list2[list_pos], xy_loc)
                     listbox.refresh_list(tech_list, tech_scroll,
                                         list_pos, item_list)
             elif event.type == pygame.MOUSEMOTION:
@@ -510,8 +533,8 @@ def change_tech(base):
                 if button.was_activated(event):
                     if button.button_id == "CHANGE":
                         g.play_click()
-                        base.studying = item_list2[list_pos]
-                        if base.studying == "Nothing": base.studying = ""
+                        this_base.studying = item_list2[list_pos]
+                        if this_base.studying == "Nothing": this_base.studying = ""
                         return
                     if button.button_id == "BACK":
                         g.play_click()
@@ -519,20 +542,20 @@ def change_tech(base):
             tmp = tech_scroll.adjust_pos(event, list_pos, item_list)
             if tmp != list_pos:
                 list_pos = tmp
-                refresh_tech(base, item_list2[list_pos], xy_loc)
+                refresh_tech(this_base, item_list2[list_pos], xy_loc)
                 listbox.refresh_list(tech_list, tech_scroll, list_pos,
                     item_list)
 
 
 
-def refresh_tech(base, tech_name, xy):
+def refresh_tech(this_base, tech_name, xy):
     xy = (xy[0]+140, xy[1])
     g.screen.fill(g.colors["white"], (xy[0]+155, xy[1], 310, 350))
     g.screen.fill(g.colors["dark_blue"], (xy[0]+156, xy[1]+1, 308, 348))
 
     #Base info
     g.print_string(g.screen, g.strings["cpu_per_day"]+" "+g.add_commas(str(
-        base.processor_time())),
+        this_base.processor_time())),
         g.font[0][20], -1, (xy[0]+160, xy[1]+5), g.colors["white"])
 
     g.print_string(g.screen, g.strings["money"]+": "+g.to_money(g.pl.cash)+
@@ -549,6 +572,14 @@ def refresh_tech(base, tech_name, xy):
             g.font[0][18], 290, (xy[0]+160, xy[1]+65), g.colors["white"])
         return
 
+    #Construction
+    if tech_name == "" or tech_name == "Construction":
+        g.print_string(g.screen, "Construction",
+            g.font[0][22], -1, (xy[0]+160, xy[1]+45), g.colors["white"])
+        string = g.strings["research_construction"]
+        g.print_multiline(g.screen, string,
+            g.font[0][18], 290, (xy[0]+160, xy[1]+65), g.colors["white"])
+        return
 
     #Jobs
     if g.jobs.has_key (tech_name):
@@ -558,12 +589,12 @@ def refresh_tech(base, tech_name, xy):
         if g.techs["Advanced Simulacra"].known == 1:
             g.print_string(g.screen,
                 g.to_money(int(
-                    (g.jobs[tech_name][0]*base.processor_time())*1.1))+
+                    (g.jobs[tech_name][0]*this_base.processor_time())*1.1))+
                     " "+g.strings["money_per_day"], g.font[0][22], -1,
                     (xy[0]+160, xy[1]+65), g.colors["white"])
         else:
             g.print_string(g.screen,
-                g.to_money(g.jobs[tech_name][0]*base.processor_time())+
+                g.to_money(g.jobs[tech_name][0]*this_base.processor_time())+
                 " "+g.strings["money_per_day"],
                 g.font[0][22], -1, (xy[0]+160, xy[1]+65), g.colors["white"])
         g.print_multiline(g.screen, g.jobs[tech_name][2],
@@ -589,12 +620,3 @@ def refresh_tech(base, tech_name, xy):
 
     g.print_multiline(g.screen, g.techs[tech_name].descript,
             g.font[0][18], 290, (xy[0]+160, xy[1]+100), g.colors["white"])
-
-
-
-
-
-
-
-
-
