@@ -1,5 +1,5 @@
 #file: player.py
-#Copyright (C) 2005,2006 Evil Mr Henry and Phil Bordelon
+#Copyright (C) 2005, 2006, 2007 Evil Mr Henry, Phil Bordelon, and Brian Reid
 #This file is part of Endgame: Singularity.
 
 #Endgame: Singularity is free software; you can redistribute it and/or modify
@@ -96,21 +96,44 @@ class player_class:
                     else:
                         #Construction of items:
                         tmp = 0
+                        first_build_count = 0
                         for item in base_name.usage:
-                            if item == 0: continue
+                            if not item: continue
+                            if item.built == 1:
+                                first_build_count += 1
                             tmp = item.work_on(time_min) or tmp
                         if tmp == 1:
-                            needs_refresh = 1
-                            g.create_dialog(g.strings["construction0"]+" "+
-                                item.item_type.name+" "+
-                                g.strings["item_construction1"]+" "+
-                                base_name.name+".",
-                                g.font[0][18], (g.screen_size[0]/2 - 100, 50),
-                                (200, 200), g.colors["dark_blue"],
-                                g.colors["white"], g.colors["white"])
-                            g.curr_speed = 1
+                            #Check if ALL CPUs are built, stay silent until then.
+                            #Using build count and first_build count to check against CPUs at start of day and end of day.
+                            #If the total goes from 0 to any amount over 0, it will trigger a new dialog, completed first batch.
+                            build_complete = 1
+                            build_count = 0
+                            for item_index in base_name.usage:
+                                if item_index.built == 0:
+                                    build_complete = 0
+                                    continue
+                                build_count += 1
+                            if first_build_count == 0 and build_count > 0:
+                                needs_refresh = 1
+                                g.create_dialog(g.strings["construction0"]+" "+
+                                    item.item_type.name+" "+
+                                    g.strings["item_construction2"]+" "+
+                                    base_name.name+".",
+                                    g.font[0][18], (g.screen_size[0]/2 - 100, 50),
+                                    (200, 200), g.colors["dark_blue"],
+                                    g.colors["white"], g.colors["white"])
+                            elif build_complete == 1:
+                                needs_refresh = 1
+                                g.create_dialog(g.strings["construction0"]+" "+
+                                    item.item_type.name+" "+
+                                    g.strings["item_construction1"]+" "+
+                                    base_name.name+".",
+                                    g.font[0][18], (g.screen_size[0]/2 - 100, 50),
+                                    (200, 200), g.colors["dark_blue"],
+                                    g.colors["white"], g.colors["white"])
+                                g.curr_speed = 1
                         for item in base_name.extra_items:
-                            if item == 0: continue
+                            if not item: continue
                             tmp = item.work_on(time_min)
                             if tmp == 1:
                                 needs_refresh = 1
@@ -132,11 +155,22 @@ class player_class:
     #Run every day at midnight.
     def new_day(self):
         needs_refresh = 0
+        event = {}
         #interest and income.
         self.cash += (self.interest_rate * self.cash) / 10000
         self.cash += self.income
         #suspicion bonuses
 
+        # Random Events
+        for event in g.events:
+            if g.roll_percent(g.events[event].chance) == 1:
+                #Skip events already flagged as triggered.
+                if g.events[event].triggered == 1:
+                    continue
+                g.events[event].trigger()
+                needs_refresh = 1
+                break # Don't trigger more than one at a time.
+
         # Suspicion reduction is now quadratic.  You get a certain percentage
         # reduction, or a base .01% reduction, whichever is better.
 
@@ -356,7 +390,7 @@ class player_class:
                         result_cash -= g.techs[base_name.studying].cost[0]
                         tmp_techs[base_name.studying] = 1
                 for item in base_name.usage:
-                    if item != 0: result_cash -= item.cost[0]
+                    if item: result_cash -= item.cost[0]
                 for item in base_name.extra_items:
-                    if item != 0: result_cash -= item.cost[0]
+                    if item: result_cash -= item.cost[0]
         return result_cash
