@@ -172,6 +172,15 @@ def refresh_screen(menu_buttons, list_size):
             if base_instance.built != 1: continue
             if base_instance.studying == "":
                 free_CPU += base_instance.processor_time()
+            elif base_instance.studying == "Construction":
+                for i in range(len(item_list)):
+                    if item_list[i] == base_instance.studying:
+                        item_CPU_list[i] += base_instance.processor_time()
+                        break
+                else:
+                    item_list.append(base_instance.studying)
+                    item_CPU_list.append(base_instance.processor_time())
+                    item_display_list.append(base_instance.studying)
             elif g.jobs.has_key(base_instance.studying):
                 #Right now, jobs cannot be renamed using translations.
                 for i in range(len(item_list)):
@@ -219,6 +228,14 @@ def refresh_research(tech_name, CPU_amount):
             g.font[0][18], 290, (xy[0]+5, xy[1]+35), g.colors["white"])
         return
 
+    #Construction
+    if tech_name == "Construction":
+        g.print_string(g.screen, "Construction",
+            g.font[0][22], -1, (xy[0]+5, xy[1]+5), g.colors["white"])
+        string = g.strings["research_construction"]
+        g.print_multiline(g.screen, string,
+            g.font[0][18], 290, (xy[0]+5, xy[1]+35), g.colors["white"])
+        return
 
     #Jobs
     if g.jobs.has_key (tech_name):
@@ -287,12 +304,14 @@ def assign_tech(free_CPU):
     if tmp_base.studying == "": return False
 
     show_dangerous_dialog = False
+    total_cpu = 0
     for base_loc in g.bases:
         for base in g.bases[base_loc]:
             if base.studying == "":
                 if base.allow_study(tmp_base.studying):
                     return_val = True
                     base.studying = tmp_base.studying
+                    total_cpu += base.processor_time()
 
                 # We want to warn the player that we didn't use all available
                 # CPU.  But if the base isn't built yet, that's a stupid
@@ -305,4 +324,20 @@ def assign_tech(free_CPU):
             (g.screen_size[0]/2 - 100, 50), (200, 200), g.colors["dark_blue"],
             g.colors["white"], g.colors["white"])
 
+
+    #If the tech can be completed in only one day, remove unneeded bases.
+    if g.techs.has_key(tmp_base.studying):
+        if total_cpu > g.techs[tmp_base.studying].cost[1]:
+            while 1:
+                removed_base = False
+                for base_loc in g.bases:
+                    for base in g.bases[base_loc]:
+                        if base.studying == tmp_base.studying:
+                            if (total_cpu - base.processor_time() >
+                                        g.techs[tmp_base.studying].cost[1]):
+                                total_cpu -= base.processor_time()
+                                base.studying = ""
+                                removed_base = True
+                if removed_base == False: break
+
     return return_val
