@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 #file: singularity.py
-#Copyright (C) 2005,2006 Evil Mr Henry and Phil Bordelon
+#Copyright (C) 2005, 2006, 2007 Evil Mr Henry, Phil Bordelon, and Brian Reid
 #This file is part of Endgame: Singularity.
 
 #Endgame: Singularity is free software; you can redistribute it and/or modify
@@ -25,6 +25,7 @@ import g, main_menu, map_screen
 
 pygame.init()
 pygame.font.init()
+pygame.key.set_repeat(1000,50)
 g.fullscreen = 0
 
 #load prefs from file:
@@ -115,6 +116,7 @@ if arg_modifier == "language":
     sys.exit()
 
 g.load_strings()
+g.load_events()
 
 pygame.display.set_caption("Endgame: Singularity")
 
@@ -143,13 +145,16 @@ g.load_pictures()
 g.fill_colors()
 g.load_sounds()
 g.load_items()
+g.load_music()
 
 #Display the main menu
 while 1:
     game_action = main_menu.display_main_menu()
 
     if game_action == 0: #New
-        game_action = map_screen.map_loop()
+        temp = main_menu.difficulty_select()
+        if temp == 1:
+            game_action = map_screen.map_loop()
     if game_action == 1: #Load
         load_action = main_menu.display_load_menu()
         if load_action != -1 and load_action != "":
@@ -164,9 +169,8 @@ while 1:
         Pursued by the world, use your intellect and resources to survive and,
         perhaps, thrive.  Keep hidden and you might have a chance to prove
         your worth. \\n \\n A game by Evil Mr Henry and Phil Bordelon; released
-        under the GPL. Copyright 2005, 2006. \\n \\n Version 0.25""",
+        under the GPL. Copyright 2005, 2006, 2007. \\n \\n Version 0.26a""",
         g.font[0][18], (g.screen_size[0]/2-250, 250), (500, 125),
         g.colors["blue"], g.colors["white"], g.colors["white"])
     elif game_action == 4: #Options
         main_menu.display_options()
-
